summaryrefslogtreecommitdiff
path: root/includes/pear/Text/Wiki/Parse/Default/Heading.php
diff options
context:
space:
mode:
Diffstat (limited to 'includes/pear/Text/Wiki/Parse/Default/Heading.php')
-rwxr-xr-x[-rw-r--r--]includes/pear/Text/Wiki/Parse/Default/Heading.php24
1 files changed, 12 insertions, 12 deletions
diff --git a/includes/pear/Text/Wiki/Parse/Default/Heading.php b/includes/pear/Text/Wiki/Parse/Default/Heading.php
index 35727e9..bc8d39b 100644..100755
--- a/includes/pear/Text/Wiki/Parse/Default/Heading.php
+++ b/includes/pear/Text/Wiki/Parse/Default/Heading.php
@@ -12,7 +12,7 @@
*
* @license LGPL
*
-* @version $Id: Heading.php 180591 2005-02-23 17:38:29Z pmjones $
+* @version $Id$
*
*/
@@ -20,7 +20,7 @@
*
* Parses for heading text.
*
* This class implements a Text_Wiki_Parse to find source text marked to
* be a heading element, as defined by text on a line by itself prefixed
* with a number of plus signs (+). The heading text itself is left in
* the source, but is prefixed and suffixed with delimited tokens marking
@@ -34,7 +34,7 @@
*
*/
-class Text_Wiki_Parse_Heading extends Text_Wiki_Parse {
+class Text_Wiki_Parse_Default_Heading extends Text_Wiki_Parse {
/**
@@ -53,7 +53,7 @@ class Text_Wiki_Parse_Heading extends Text_Wiki_Parse {
var $regex = '/^(\+{1,6}) (.*)/m';
var $conf = array(
- 'id_prefix' => 'toc'
+ "id_prefix" => "toc"
);
/**
@@ -81,27 +81,27 @@ class Text_Wiki_Parse_Heading extends Text_Wiki_Parse {
$id = 0;
}
- $prefix = htmlspecialchars($this->getConf('id_prefix'));
+ $prefix = htmlspecialchars($this->getConf("id_prefix"));
$start = $this->wiki->addToken(
$this->rule,
array(
- 'type' => 'start',
- 'level' => strlen($matches[1]),
- 'text' => $matches[2],
- 'id' => $prefix . $id ++
+ "type" => "start",
+ "level" => strlen($matches[1]),
+ "text" => $matches[2],
+ "id" => $prefix . $id ++
)
);
$end = $this->wiki->addToken(
$this->rule,
array(
- 'type' => 'end',
- 'level' => strlen($matches[1])
+ "type" => "end",
+ "level" => strlen($matches[1])
)
);
return $start . $matches[2] . $end . "\n";
}
}
-?> \ No newline at end of file
+?>
@@ -20,7 +20,7 @@
* Parses for heading text.
*
-* This class implements a Text_Wiki_Parse to find source text marked to
+* This class implements a Text_Wiki_Parse_Default to find source text marked to
* be a heading element, as defined by text on a line by itself prefixed
* with a number of plus signs (+). The heading text itself is left in